@@ -1,5 +1,7 @@
 """
-Main interface for qldb service literal definitions.
+Type annotations for qldb service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/literals.html)
 
 Usage::
 
